Documentation
¶
Overview ¶
Package at provides timestamp handling with millisecond precision.
Index ¶
Constants ¶
const ( RFC3339Milli string = "2006-01-02T15:04:05.000Z" RFC3339MilliWithZone string = "2006-01-02T15:04:05.000-07:00" )
Millisecond time formats to comply with W3C datetime format that contains rules for local timezones so that they always include a ":".
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type LocalTime ¶
LocalTime ensures the local time information is included in the timestamp.
func LocalTimeNow ¶
LocalTimeNow is used to provide the current time in the provided location.
func ParseLocalTime ¶
ParseLocalTime attempts to read in the provided time data which hopefully includes a zone, but is not necessarily guaranteed.
func (LocalTime) MarshalJSON ¶
MarshalJSON provides the local time in JSON format.
func (*LocalTime) UnmarshalJSON ¶
UnmarshalJSON parses the provided local time JSON data.
type Timestamp ¶
Timestamp represents the basic time wrapper to be used in timestamps with millisecond precision.
func ParseTimestamp ¶
ParseTimestamp attempts to parse the timestamp string.
func (Timestamp) MarshalJSON ¶
MarshalJSON provides the timestamp in JSON format
func (*Timestamp) UnmarshalJSON ¶
UnmarshalJSON uses our timestamp parser.